@@ -19,7 +19,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our $VERSION = '0.51';
+our $VERSION = '0.53';
 
 bootstrap Sys::CPU $VERSION;
 
@@ -58,6 +58,13 @@ None by default.
 
 MZSanford
 
+=head1 MAINTENANCE
+
+Marc Koderer
+
+=head1 LICENSE
+
+
 =head1 SEE ALSO
 
 perl(1), sysconf(3)
